Before & After: Replacing Tiny Details in This Kitchen Made a Big Difference — Reader Kitchen Remodel | The Kitchn
Description: Kaycee shared her kitchen remodel with us as part of our Big Reveal contest earlier this year, and it's one of the best examples of just how much of a difference you can make in your space by paying attention to the little things. After all, the devil is in the details. Take a look at how Kaycee's kitchen looks now.

# Before & After: Replacing Tiny Details in This Kitchen Made a Big Difference

Reader Kitchen Remodel

Kaycee shared her kitchen remodel with us as part of our Big Reveal contest earlier this year, and it's one of the best examples of just how much of a difference you can make in your space by paying attention to the little things. After all, the devil is in the details.

Take a look at how Kaycee's kitchen looks now.

Doesn't it look so much fresher? Kaycee writes that the cabinets were in good shape, but that they just needed a few improvements. First, she replaced the plastic hardware with silver metal hardware giving them a more expensive look (while not costing that much!).

Next, she noted that the edging on the cabinets was the only thing that was betraying their age. So she removed it and replaced it with new laminate edging. Yes, it was an arduous process, but it made the cabinets look brand new for a fraction of the cost.

Kaycee also replaced some of the appliances, and gave the walls a fresh paint job.

Possibly our favorite transformation is the built-in shelving in the dining area. Kaycee removed the scalloped molding and painted the wall to provide some much needed contrast. Then it was all about styling. Take a look at how it turned out.

Looks fantastic! You can see more of Kaycee's remodel here.

Have a remodel or a DIY project to share with us?
Submit it here!

### More posts in this series

###### Before & After

Previous
Before & After: A Quirky Kitchen Gets a Farmhouse Makeover
You are on the last post of the series.

(Image credits: Kaycee - The Big Reveal)

## Faith’s Daily Find

1. Ethiopian Hand Towels from Creative Women
2. FIKA Chocolate-Covered Pills
3. Champagne Flutes from Govino

See more